
setClass(
		"mcqMetadata",
		slots = list(metadata="data.frame",samples="data.frame"),
		validity=function(object){
			cat("Checking mcqMetadata validity\n")
			if ('msrunfile' %in% colnames(object@metadata)) {
				cat ("mcqMetadata shouldn't have an msrunfile column\n")
				return(FALSE)
			}
			if ('msrun' %in% colnames(object@metadata)) {
				cat ("mcqMetadata shouldn't have an msrun column\n")
				return(FALSE)
			}
			cat("mcqMetadata object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcqData",
		slots = list(quantipeptides="data.frame",samples="list", groups="list",
				proteins="list",peptidesmh="data.frame", observedin="data.frame",quantify="matrix"),
		validity=function(object){
			cat("Validity\n")
			return(TRUE)
		}
)


setClass(
		"mcqProtList",
		#very simple structure : proteins is a list with named elements
		# the names are the protein accessions
		# the elements are the protein description
		slots = list(proteins="character"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcqProtList object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcqProtPep",
		slots = list(proteins="data.frame",peptides="data.frame", metadata="mcqMetadata", nona="data.frame"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcqProtPep object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcqProtValue",
		slots = list(proteins="data.frame",metadata="mcqMetadata",protval="data.frame",samples="data.frame"),
		validity=function(object){
			cat("Checking validity\n")
			if("protein" %in% colnames(object@proteins)) {
				cat("mcqProtValue@proteins should not have a protein column\n")
				return(FALSE)
			}
			if("descr" %in% colnames(object@proteins)) {
			}
			else {
				cat("mcqProtValue@proteins should have a descr column\n")
				return(FALSE)
			}
			if("accession" %in% colnames(object@proteins)) {
			}
			else {
				cat("mcqProtValue@proteins should have an accession column\n")
				return(FALSE)
			}
			cat("mcqProtValue object is valid\n")
			return(TRUE)
		}
)


setClass(
		"mcqProtPCA",
		slots = list(proteins="data.frame",metadata="mcqMetadata",samples="data.frame",pca="list"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcqProtPCA object is valid\n")
			return(TRUE)
		}
)

setClass(
		"mcqPeptidePCA",
		slots = list(peptides="data.frame", proteins="data.frame",metadata="mcqMetadata",samples="data.frame",pca="list"),
		validity=function(object){
			cat("Checking validity\n")
			cat("mcqPeptidePCA object is valid\n")
			return(TRUE)
		}
)



setClass(
		"mcqProtAnova",
		slots = list(proteins="data.frame",metadata="mcqMetadata",samples="data.frame", paramlist = "list", protval="data.frame", resultanov="data.frame", resulttukey="data.frame"),
		validity=function(object){
			cat("Checking validity\n")

			cat("mcqProtAnova object is valid\n")
			return(TRUE)
		}
)

setClass(
		"mcqSpectralcounting",
		slots = list(metadata="mcqMetadata", count="data.frame", resultanov="data.frame", paramlist = "list"),
		validity=function(object){
			cat("Check mcqSpectralcounting validity\n")
			#protein          msrun           count
			cat("mcqSpectralcounting object is valid\n")
			return(TRUE)
		}
)

setClass(
		"mcqPeakcounting",
		slots = list(metadata="mcqMetadata", count="data.frame", resultanov="data.frame", paramlist = "list"),
		validity=function(object){
			cat("Check mcqPeakcounting validity\n")
			#protein          msrun           count
			cat("mcqPeakcounting object is valid\n")
			return(TRUE)
		}
)

