


mcqPlotPeakWidth <- function (mcq, pdf=NULL, nclass=40) {
	if (class(mcq) == "mcqProtPep") {
		############### validation des données et suppression des données aberrantes
		## Vérification de la quantification par check de la largeur moyenne des pic
		width_peak <- mcq@peptides[,'rtend'] - mcq@peptides[,'rtbegin']
	}
	else {
		if (class(mcq) != "mcqData") {
			stop("input is not an mcqData or mcqProtPep object")
		}
		if (nrow(mcq@quantipeptides)[[1]] == 0) {
			stop("no quantification results")
		}
		############### validation des données et suppression des données aberrantes
		## Vérification de la quantification par check de la largeur moyenne des pic
		width_peak <- mcq@quantipeptides[,'rt_end'] - mcq@quantipeptides[,'rt_begin']
	}
	#pdf("peak_width.pdf",title="peak width")

	if (is.null(pdf)){
		#par(ask=TRUE)
		# a single hist : no need to pause
	}
	else{
		pdf(pdf)
	}
	hist(width_peak,main="Chromatographic peak width",xlab="time (seconds)",nclass=nclass)
	mtext(paste("Min. : ",summary(width_peak)[1]," 1st Qu.: ",summary(width_peak)[2]," Median : ",summary(width_peak)[3]," 3rd Qu. : ",summary(width_peak)[5]," Max. : ",summary(width_peak)[6],sep=""),side=3)
	if (!is.null(pdf)){
		dev.off()
	}

}


mcqPlotRetentionTimeSd <- function (mcq, pdf=NULL,limit = NULL, nclass=100) {
	if (class(mcq) == "mcqProtPep") {
		## Suppression des peptiz dont l'écart-type du temps de rétention est trop élevé
		peptidgroup=as.factor(paste(mcq@peptides$peptide,mcq@peptides$group,sep='-'))

		sdrt=aggregate(mcq@peptides$rt,list(peptidgroup),FUN=sd)
	}
	else {
		if (class(mcq) != "mcqData") {
			stop("input is not an mcqData or mcqProtPep object")
		}
		if (nrow(mcq@quantipeptides)[[1]] == 0) {
			stop("no quantification results")
		}
		peptidgroup=as.factor(paste(mcq@peptides$peptide,mcq@quantify[mcq$quantipeptides$quantify_id,'group_id'],sep='-'))
		## Suppression des peptiz dont l'écart-type du temps de rétention est trop élevé
		sdrt=aggregate(mcq@quantipeptides$rt,list(peptidgroup),FUN=sd)
	}

	if (is.null(pdf)){
		#par(ask=TRUE)
		# a single hist : no need to pause
	}
	else{
		pdf(pdf)
	}
	if (is.null(limit)) {
		hist(sdrt$x,nclass=nclass,main="Standard deviation of peptide-mh/z retention time",xlab="time (seconds)")
	}
	else {
		hist(sdrt$x,nclass=nclass,main="Standard deviation of peptide-mh/z retention time",xlab="time (seconds)",xlim = c(0,limit))
	}
	mtext(paste("Min. : ",summary(sdrt$x)[1]," 1st Qu.: ",summary(sdrt$x)[2]," Median : ",summary(sdrt$x)[3]," 3rd Qu. : ",summary(sdrt$x)[5]," Max. : ",summary(sdrt$x)[6],sep=""),side=3)
	if (!is.null(pdf)){
		dev.off()
	}
}


mcqDropPeakWidth <- function (object, cutoff) {
	if (class(object) == "mcqProtPep") {
		width_peak_ok <- ((object@peptides[,'rtend'] - object@peptides[,'rtbegin']) <= cutoff)
		nbpeptides <- length(unique(object@peptides$peptide))
		nbprot <- length(unique(object@proteins$protein))

		object@peptides <- object@peptides[width_peak_ok,]
		object@peptides <- drop.levels(object@peptides)

		object@proteins <- object@proteins[object@proteins$peptide %in% object@peptides$peptide,]
		object@proteins <- drop.levels(object@proteins)

		if (nrow(object@metadata@metadata) > 0){
			object@metadata@metadata$bidonnage <- rownames(object@metadata@metadata)
			object@metadata@metadata <- object@metadata@metadata[unique(object@peptides$msrun),]
			object@metadata@metadata$bidonnage <- NULL
			object@metadata@metadata <- drop.levels(object@metadata@metadata)
		}

		nbpeptidesafter <- length(unique(object@peptides$peptide))
		nbprotafter <- length(unique(object@proteins$protein))
		cat (paste((nbpeptides - nbpeptidesafter), " peptides dropped\n", sep=""))
		cat (paste((nbprot - nbprotafter), " proteins dropped\n", sep=""))

		return (object)
	}
	else {
		stop(paste("the object ",class(object)," is not taken into account by mcqDropPeakWidth"))
	}
}



mcqDropRetentionTimeSd <- function (mcq, cutoff) {
	if (class(mcq) == "mcqProtPep") {
		#peptidgroup=as.factor(paste(mcq@peptides$peptide,mcq@peptides$group,sep='-'))
		#sdrt=aggregate(mcq@peptides$rt,list(peptidgroup),FUN=sd)
		peptidgroup=as.factor(mcq@peptides$peptiz)
		sdrt=aggregate(mcq@peptides$rt,list(peptidgroup),FUN=sd)
	}
	else {
		if (class(mcq) != "mcqData") {
			stop("input is not an mcqData or mcqProtPep object")
		}
		if (nrow(mcq@quantipeptides)[[1]] == 0) {
			stop("no quantification results")
		}
		#peptidgroup=as.factor(paste(mcq@peptides$peptide,mcq@quantify[mcq$quantipeptides$quantify_id,'group_id'],sep='-'))
		## Suppression des peptiz dont l'écart-type du temps de rétention est trop élevé
		#sdrt=aggregate(mcq@quantipeptides$rt,list(peptidgroup),FUN=sd)
		peptidgroup=as.factor(mcq@peptides$peptiz)
		sdrt=aggregate(mcq@quantipeptides$rt,list(peptidgroup),FUN=sd)

	}
	#On enlève les quelques cas particuliers où l'écart-type est supérieur à 15 (20 ?) car correspond certainement à un mismatch
	thr_sdrt=cutoff # paramètre à changer en fonction de l'histogramme
	mauvaispep=sdrt[!is.na(sdrt$x) & sdrt$x>thr_sdrt,] # renvoie les lignes de rt pour lesquelles sdrt>thr_sdrt.
	mauvaispep=drop.levels(mauvaispep$Group.1)
	cat (paste(length(mauvaispep), " peptiz quantifications dropped\n", sep=""))
	#length(mauvaispep)
	if (class(mcq) == "mcqProtPep") {
		nbpeptides <- length(unique(mcq@peptides$peptide))
		mcq@peptides <- mcq@peptides[!(peptidgroup %in% mauvaispep),]
		mcq@peptides <- drop.levels(mcq@peptides)
		nbpeptidesafter <- length(unique(mcq@peptides$peptide))
		cat (paste((nbpeptides - nbpeptidesafter), " peptides dropped\n", sep=""))
		nbprot <- length(unique(mcq@proteins$protein))
		mcq@proteins <- mcq@proteins[mcq@proteins$peptide %in% mcq@peptides$peptide,]
		mcq@proteins <- drop.levels(mcq@proteins)
		nbprotafter <- length(unique(mcq@proteins$protein))
		cat (paste((nbprot - nbprotafter), " proteins dropped\n", sep=""))

		if (nrow(mcq@metadata@metadata) > 0){
			mcq@metadata@metadata$bidonnage <- rownames(mcq@metadata@metadata)
			mcq@metadata@metadata <- mcq@metadata@metadata[unique(mcq@peptides$msrun),]
			mcq@metadata@metadata$bidonnage <- NULL
			mcq@metadata@metadata <- drop.levels(mcq@metadata@metadata)
		}

	}
	else {
		mcq@quantipeptides <- mcq@quantipeptides[!(peptidgroup %in% mauvaispep),]
		mcq@quantipeptides <- drop.levels(mcq@quantipeptides)

	}
	return (mcq)
}

