


mcqWriteMetadataCsv = function(object, outfile) {
	if (class(object) == "mcqProtPep") {
		tab_sample_id = levels(object@peptides[,'msrun'])

		metadata = data.frame(
				msrun=character(length(tab_sample_id)),
				stringsAsFactors=FALSE)

		metadata$msrun <- tab_sample_id

		tabmsrunfile = unique(object@peptides[,c('msrun','msrunfile')])
		#print(tabmsrunfile)
		metadata<-merge(metadata,tabmsrunfile, by="msrun", all.x=TRUE)
		#rownames(metadata) <- metadata$msrun
		#metadata$msrun <-NULL
		#print(metadata)
	}
	else if (class(object) == "mcqSpectralcounting") {
		if (!('msrun' %in% colnames(object@count))) {
			msrunfileList <- unique (object@count$msrunfile)
			msrunnames <- paste ("samp", seq(1:length(msrunfileList)), sep="")
			dfmsrun <- data.frame(msrunfile=msrunfileList, msrun=msrunnames)

			object@count <- merge(object@count, dfmsrun, by="msrunfile")
		}
		tab_sample_id = levels(object@count[,'msrun'])

		metadata = data.frame(
				msrun=character(length(tab_sample_id)),
				stringsAsFactors=FALSE)

		metadata$msrun <- tab_sample_id

		tabmsrunfile = unique(object@count[,c('msrun','msrunfile')])
		#print(tabmsrunfile)
		metadata<-merge(metadata,tabmsrunfile, by="msrun", all.x=TRUE)
		#rownames(metadata) <- metadata$msrun
		#metadata$msrun <-NULL
		#print(metadata)

	}
	else {
		stop(paste("the class \"", class(object),"\" is not taken into account by mcqWriteMetadataCsv",sep=""))
	}
	write.table(metadata, outfile,quote= FALSE, sep="\t",row.names=FALSE)
}


privCheckMetadataIn = function (tabin) {
	metadata = data.frame(
			msrun=character(length(tabin[,1])),
			stringsAsFactors=FALSE)
	samples = data.frame(
			msrun=character(length(tabin[,1])),
			stringsAsFactors=FALSE)

	if('msrun' %in% colnames(tabin))
	{
		rownames(metadata) <-  tabin[,'msrun']
		rownames(samples) <-  tabin[,'msrun']
		metadata[,'msrun']  <- NULL
		tabin[,'msrun'] <- NULL
	}
	else {
		stop("ERROR : metadata dataframe does not contain expected column 'msrun'\n")
		return (NULL)
	}
	if('msrunfile' %in% colnames(tabin))
	{
		samples[,'msrunfile'] <- tabin[,'msrunfile']
		tabin[,'msrunfile'] <- NULL
		samples[,'msrun']  <- NULL
	}
	else {
		stop("ERROR : metadata dataframe does not contain expected column 'msrunfile'\n")
		return (NULL)
	}
	#cat ("for (i in colnames(tabin))\n")
	#cat ('coucou')
	for (i in colnames(tabin)) {
		#these columns are factors
		metadata[,i] <- factor(tabin[,i])
	}
	#cat (print (metadata))
	return (list(metadata= metadata, samples = samples))
}


read.mcqMetadataCsv = function(filename) {
	## Lecture des metadonnées (facteurs associés aux échantillons MS)
	tabin=read.table(filename, header=TRUE, sep="\t", dec=".")
	metadata <- privCheckMetadataIn(tabin)
	mcqMetadata <- new ("mcqMetadata", metadata = metadata$metadata, samples=metadata$samples)
	return(mcqMetadata)
}

read.mcqMetadataOds = function(filename) {
	## Lecture des metadonnées (facteurs associés aux échantillons MS)
	tabin=as.data.frame(read.ods(filename))


	#tabin = as.data.frame(tabin)
	coln <- tabin[1,]
	#print(coln)
	tabin <- tabin[2:length(tabin$A),]
	colnames(tabin)<- coln
	#print(tabin)
	metadata <- privCheckMetadataIn(tabin)
	#print(metadata$metadata)
	mcqMetadata <- new ("mcqMetadata", metadata = metadata$metadata, samples=metadata$samples)
	return(mcqMetadata)
}



privCheckMetadataCoherence <- function(object) {
	msrunList <- NULL

	if (class(object) == "mcqProtPep") {
		msrunList <- unique(object@peptides$msrun)
	}
	if (class(object) == "mcqSpectralcounting") {
		msrunList <- unique(object@count$msrun)
	}
	if (class(object) == "mcqData") {
		# où sont les msruns ?
		#msrunList <- unique(object@peptides$msrun)
	}
	if (!is.null(msrunList)) {
		if (nrow(object@metadata@metadata) != length(msrunList)){
			stop("the number of msrun is different between mcqMetadata and treated object")
		}

		for (msrun in msrunList) {
			if (msrun %in% rownames(object@metadata@metadata)) {

			}
			else {
				stop(paste("the msrun ",msrun," is not described in your metadata"))
			}
		}

		for (msrun in rownames(object@metadata@metadata)) {
			if (msrun %in% msrunList) {

			}
			else {
				stop(paste("the msrun ",msrun," does not exists in your object"))
			}
		}
	}
}

mcqMergeMetadata = function(object, metadata) {
	if (class(metadata) != "mcqMetadata") {
		stop("second argument is not an mcqMetadata object")
	}
	if ((class(object) == "mcqProtPep")||(class(object)=="mcqSpectralcounting")||(class(object) == "mcqData")) {
		#merge des facteurs dans le tableau peptides
		object@metadata <- metadata

		if (class(object)=="mcqSpectralcounting") {
			if (!("msrun" %in% colnames(object@count))) {
				tsamples <- object@metadata@samples
				tsamples$msrun <- rownames(object@metadata@samples)
				object@count <- merge(object@count,tsamples, by.x="msrunfile", by.y="msrunfile", all.x=T, all.y=F)
			}
		}

		privCheckMetadataCoherence(object)

	}
	else {
		stop("input is not an mcqData or mcqProtPep or mcqSpectralcounting object")
	}
	return (object)
}
