
#########################################################################################################################################################
########################################################## Installation du paquet MassChroqR ############################################################
#########################################################################################################################################################

# tous les fichiers nécessaires sont téléchargeables à cette adresse :
#http://pappso.inra.fr/downloads/2014_12_formation_PAPPSO/

# télécharger le fichier .tar.gz
# http://pappso.inra.fr/downloads/2014_12_formation_PAPPSO/MassChroqR_0.2.0.tar.gz
# et placer le dans votre répertoire de travail R
# lancer R en tapant "R" dans un terminal

# installation des dépendances
	install.packages('XML')
	install.packages('gdata')
	install.packages('data.table')
	install.packages('readODS')
	install.packages('VIM')
	install.packages('reshape2')
	install.packages('ade4')
	install.packages('multcomp')
	install.packages('gplots')
	install.packages('clValid')

# installation du paquet MassChroqR (remplacer /chemin/vers/ par votre arborescence)
	install.packages('/chemin/vers/MassChroqR_0.2.0.tar.gz')

# chargement du paquet
	library('MassChroqR')

# changement du répertoire de travail (remplacer /chemin/vers/repertoire_de_travail par votre arborescence)
	setwd ('/chemin/vers/repertoire_de_travail')



############################################################################################################################################################################
################################# Mise en forme des données  ###############################################################################################################
############################################################################################################################################################################
### NB : le fichier XIC_result_prot.tsv ne doit pas contenir d'apostrophes sous peine de lecture incomplète !!

################################# Création de l'objet protPep

# chargement des données d'identification et de quantification sorties de MassChroQ: mettre le fichier prot en premier
### NB: les aires sous le pic sont transformées en log (base 10) à cette étape
	protPep <- read.mcqProtPep('/gorgone/pappso/formation/Decembre2014/XIC_result_prot.tsv', '/gorgone/pappso/formation/Decembre2014/XIC_result_pep.tsv')

# visualiser la structure de l'objet protPep
	str(protPep)

# affichage du résumé du contenu de l'objet protPep
	summary (protPep)
#number of proteins :
#number of XICs :
#number of peptiz : (=  peptide-charge)
#number of peptides :
#number of samples :


################################# Création des métadata contenant la description des échantillons

# export d'un template dans lequel pourront être ajouté les métadata
	mcqWriteMetadataCsv(protPep, 'metadata.csv')

# Ajout des metadata: ouvrir le fichier outfile.csv sous libreoffice ou excel, ajouter des colonnes (par exemple:traitement, rep , génotype, etc. ) permettant de décrire les échantillons et enregistrer en conservant le format csv

# import des métadata
	metadata <- read.mcqMetadataOds('/gorgone/pappso/formation/Decembre2014/metadata.ods')

# Ajout des métadata à l'objet protPep
	protPep <- mcqMergeMetadata(protPep, metadata)



############################################################################################################################################################################
################################# Vérification de la qualité des données de chromatographie ################################################################################
############################################################################################################################################################################
### NB: on vérifie la largeur moyenne des pics et la déviation des temps de rétention pour éviter les missmatch et les erreurs eventuelles d'attribution de masse à un pic

# affichage de l'histogramme de distribution de la largeur moyenne des pics
	mcqPlotPeakWidth(protPep)					# affichage à l'écran
	mcqPlotPeakWidth(protPep, pdf='peak.pdf') 	# pour enregistrer le graphique sous format pdf

# suppression des XICs dont la largeur est trop longue (temps de rétention en secondes. ici, 100 sec)
	protPep <- mcqDropPeakWidth(protPep, cutoff=100)

# affichage du résumé du contenu de l'objet protPep après suppression des peptides
	summary(protPep)

# affichage de l'histogramme de distribution de la déviation des temps de rétention
	mcqPlotRetentionTimeSd(protPep)							# affichage à l'écran et paramètre "limit" par défaut
	mcqPlotRetentionTimeSd(protPep, pdf="RT.pdf",limit=40)  # limiter l'affichage des temps de rétention à 40s maximum (ici)

# suppression des peptides ayant une déviation supérieure à un seuil à déterminer en fonction de l'histogramme précédent (ici, 20 sec)
	protPep <- mcqDropRetentionTimeSd(protPep, cutoff=20)

# affichage du résumé du contenu de l'objet protPep après suppression des peptides
	summary(protPep)

# Statistiques exploratoires : ACP sur les peptides (peptiz / échantillons)
	peptidepca <- mcqNewPeptidePCA(protPep)

# Statistiques exploratoires : ACP sur les peptides (peptiz / extraction)
#	peptidepca_extraction <- mcqNewPeptidePCA(protPep, "extraction")

# écriture du résultat de l'ACP dans un fichier pour un traitement dans un logiciel externe
	mcqWriteCsv(peptidepca, csv="peptidepca.csv")

# visualisation des axes de l'ACP

	mcqPlotPeptidePCA(peptidepca, colors="extraction")


############################################################################################################################################################################
################################# Analyse par 'Peakcounting' (Variations qualitatives) ################################################################################
############################################################################################################################################################################


# comptage du nombre de 'peak' (= peptide-charge) par protéine dans chaque échantillon
	pkcount <- mcqNewPeakcounting(protPep)

# export en format csv
	mcqWriteCsv(pkcount, csv='pkcount.csv')

# visualisation du nombre total de 'peaks', estimation de la qualité des échantillons et éventuellement enlever des échantillons
	mcqPlotPeakcountingPeakPerSamples(pkcount)

#si un échantillon est "hors type", on peut le supprimer du jeu de données :
	summary(protPep)
	bis <- mcqDrop(protPep, 'msrun', 'samp11')
	summary(bis)
#dans ce cas, il faudra recompter le nombre de 'peak' sur ce nouveau jeu de données

# Statistique décisionnelle : test de Kruskal sur les données de 'Peakcounting'
	#si un facteur
	pkcount.anova <- mcqPeakcountingAnova(pkcount,'extraction', kruskal=T)
	#si plusieurs facteurs, créer une nouvelle colonne dans le fichier metadata pour les concaténer
	# (le test de Kruskal ne fonctionne que sur un facteur)

# Créer un tableau contenant le counting de peak par protéines et les résultats de l'ANOVA
	dfpeakcountinganova <- mcqGetDataframe(pkcount.anova)
# Affichage des premières lignes du dataframe obtenu
	head(dfpeakcountinganova)

# Exporter les résultats de l'ANOVA au format csv
	mcqWriteComparCsv(pkcount.anova, 'pkcount_anova.csv')

# pvalue => seuil de pvalue
# mindiff => différence minimum entre min max (nombres de pics)
	pkcount.anova.signif <- mcqSelectPeakcountingAnovaSignif(pkcount.anova, pvalue=0.01,mindiff=5, factor='extraction')

# Boxplot des protéines signif en fonction du facteur choisi
# (par défaut, c'est le facteur utilisé dans l'ANOVA qui sera pris en compte)
	mcqPlotPeakcountingAnova(pkcount.anova.signif, factor="extraction", pdf='AnovaSignifPeakCounting.pdf')

# Créer un tableau contenant les résultats de l'anova du peak counting et les résultats de l'anova pour les protéines avec un effet traitement significatif
	dfpeakcountinganovasignif <- mcqGetDataframe(pkcount.anova.signif)

# Exporter les résultats pour les protéines significatives au format csv
	mcqWriteCsv(pkcount.anova.signif, 'pkcount_anova_signif.csv')

# Combien de protéines avons-nous maintenant ?
	summary (protPep)



############################################################################################################################################################################
################################# Analyse quantitative (XIC)   #############################################################################################################
############################################################################################################################################################################

################################# Normalisation des données (les aires sont en log10)

# Visualisation des histogrammes de distribution des intensités de peptide dans chaque échantillon
	mcqPlotDistribQlog(protPep)

# Visualisation des histogrammes de distribution des différences des log d'intensité de peptide entre un échantillon donné et l'échantillon choisi comme référence (ici samp0)
	mcqPlotDistribQlogDiffRef(protPep, 'samp0', pdf='distrib_visu.pdf')

# Visualisation de la corrélation entre les intensités de peptides mesurées dans un échantillon donné et celles mesurées dans l'échantillon de référence (ici samp0)
	mcqPlotDistribQlogCometDiff(protPep, 'samp0')

# Normalisation par la médiane des différences d'intensité de peptides
	protPep <- mcqNormalizeBySampleref(protPep, 'samp0')

# Visualisation de l'effet de la normalisation
	mcqPlotNormalizationEffect(protPep, pdf='normalization_effect.pdf')


################################# Filtre des données : sélection des peptides reproductibles, des peptides spécifiques et des peptides corrélés d'une même protéine

# Histogramme du nombre d'échantillons dans lesquels un peptide a été quantifié
	mcqPlotPeptideRepeatability(protPep, pdf='PeptideRepetables.pdf')

# Suppression des peptides non répétables (présents dans moins de 5% des échantillons)
# pct.max.mq => % max de valeurs manquantes
	protPep <- mcqSelectRepeatablePeptides(protPep, pct.max.mq=0.05)

#Quantification des protéines uniquement avec leurs peptides spécifiques
# Histogramme du nombre de protéines par peptide
	mcqPlotPeptidesSharedByProt(protPep, pdf = 'PeptidesPartages.pdf')

# Suppression des peptides communs à plusieurs protéines
	protPep <- mcqDropSharedPeptides(protPep)

# Selon nombre de modalités du facteur choisir étape a ou étape b
# a /Si le facteur "traitement" présente au moins 3 conditions (modalités) : filtre sur la correlation entre les peptides d'une même protéine
	protPep <- mcqDropUncorrelatedPeptides(protPep, 'extraction')
# b /Si le facteur "traitement" présente moins de 3 modalités : on ne garde que les protéines quantifiées par au moins 2 peptides
	protPep = mcqSelect2pepbyprot(protPep,'extraction')


################################# Imputation des valeurs manquantes par régression linéaire
	protPepnona <- mcqDataImputations(protPep, 'extraction')


################################# Représentation ACP à partir des intensités de peptide
	pcapeptide <- mcqNewPeptidePCA(protPep)
# représentation des 5 premiers axes de l'ACP.
# On choisit de colorier les échantillons en fonctions du facteur traitement (colors='traitement')
	mcqPlotPeptidePCA(pcapeptide, colors='extraction', pdf='peptide_acp.pdf')
# coordonnées spatiales des échantillons
	mcqWriteCsv(pcapeptide, 'pcapeptide.csv')
# écriture des composantes (peptides/z)
	mcqWriteCsv(pcapeptide, 'pcapeptide_comp.csv', comp=T)


################################# Calcul de la quantité par protéine

# Calcul des quantités de protéine (somme des peptides)
	qprot <- mcqNewProteinValue(protPepnona)

# Histogramme de distribution des écart-types des quantités de protéine
	mcqPlotProteinValueSd(qprot, pdf='SD_logQNorm.pdf')
	head(qprot@protval)

#Création d'un tableau à 2 dimensions : échantillons/protéines
	tacp <- mcqGetCompar(qprot)
	head(tacp)

# Export au format tabulé
	mcqWriteComparCsv(qprot, 'tacp_na.csv')

# dans les cas où il n'y avait pas de peptide de la protéine présent dans l'échantillon, on a encore un NA.
# on remplace le NA par la valeur min trouvée pour cette protéine dans l'expérience.
	qprot <- mcqReplaceNaProteinValueByMin(qprot)

	mcqWriteComparCsv(qprot, 'tacp_nona.csv')

	mcqPlotProteinValueSd(qprot, pdf ='SD_logQNormMIN.pdf')



# Elimination des protéines qui ne varient pas beaucoup
# cutoff => seuil minimum accepté pour l'écart type en valeur absolue (0.05=trop faible pour une valeur absolue)
# Regarder l'ecart type et adapter en fonction
	test <- mcqDropProteinValueSd(qprot,cutoff=0.05)
	mcqPlotProteinValueSd(test)
	mcqPlotProteinValueSd(qprot)

################################# Représentation ACP à partir des quantités de protéine
	pca <- mcqNewProteinPCA(qprot)
# export du résultat de l'ACP dans un fichier pour manipulations dans un logiciel externe
# coordonnées spatiales des échantillons
	mcqWriteCsv(pca, 'proteinpca.csv')
# écriture des composantes (protéines)
	mcqWriteCsv(pca, 'proteinpca_comp.csv', comp=T)

#visualisation des résultats de l'ACP (écrit dans un fichier pdf)
	mcqPlotProteinPCA(pca, colors='extraction', pdf='acp.pdf')

################################# ANOVA, Heatmap et clustering sur les protéines

#ANOVA à 1 facteur
	anova <- mcqNewProteinAnova (qprot, 'extraction')
#si plusieurs facteurs
#	anova <- mcqNewProteinAnova (qprot,c('extraction','rep.bis'))

# Visualisation de l'histogramme des pvalues de l'ANOVA
	mcqPlotAnovaPvalueHist(anova, "extraction")
	mcqPlotAnovaPvalueHist(anova, "extraction", pdf="anova_hist_extraction.pdf")
# 0.05 => seuil de signif sur le facteur "extraction"
	anova.signif <- mcqSelectProteinAnovaSignif(anova, 0.05, factor='extraction')
# Boxplot des protéines signif
	mcqPlotProteinAnova(anova.signif)
# Ecriture des résultats de l'ANOVA dans un fichier :
# => totalité des résultats
	mcqWriteCsv(anova, 'anova.csv')
# => uniquement les protéines signif
	mcqWriteCsv(anova.signif, 'anova_signif.csv')

# on récupère la liste des protéines significatives déterminée par l'ANOVA
	protlist.signif <- mcqGetProtlist(anova.signif)
# on sélectionne les protéines quantifiées qui sont présentes dans la liste
	qprot.signif <- mcqSelectProtlist(qprot, protlist.signif)

# on peut visualiser ces protéines sur un heatmap en fonction d'un facteur
	mcqPlotHeatmap(qprot.signif, factor="extraction")
	mcqPlotHeatmapMeanRep(qprot.signif,factor="extraction",'classification_by_conditions.pdf')

# Regroupement des protéines en clusters
	mcqPlotCluster(qprot.signif,factor="extraction",nbclust=8,pdf='cluster.pdf')
	mcqPlotClusterMeanRep(qprot.signif,factor="extraction", nbclust=8, pdf='cluster_by_conditions.pdf')

# ecriture des infos clusters
	mcqClusterMeanRepInfoWriteCsv(qprot.signif,factor="extraction", nbclust=8, file='infos_cluster.csv')



################################## Récupération des informations de Spectral Counting ##################################################
# Pour éventuellement merger les données de Spectral Counting, Peak counting et XIC

# ATTENTION pour l'instant preparer la feuille comparspectra dans un fichier csv (bug read.ods pour fichier avec plusieurs onglets)
	spectral.count = read.mcqSpectralcounting('/gorgone/pappso/formation/Decembre2014/comparspectra.csv')

# merge avec les metadata
	spectral.count = mcqMergeMetadata(spectral.count, metadata)

	spectral.count.anova <- mcqSpectralcountingAnova(spectral.count,'extraction', kruskal=T)

#ecriture fichier spectral counting + pvalue
	mcqWriteComparCsv(spectral.count.anova, 'spectralcount.csv')


# Statistique décisionnelle : ANOVA sur les données de 'SpectralCounting'
# 0.01 => seuil de pvalue
# 5 => différence minimum entre min max (nombres de pics)
	spectral.count.anova.signif <- mcqSelectSpectralcountingAnovaSignif(spectral.count.anova, 0.01,5, factor='extraction')
# => faire un boxplot des protéines signif en fonction du facteur choisi
# (par défaut, c'est le facteur utilisé dans l'anova qui sera pris en compte)
	mcqPlotSpectralcountingAnova(spectral.count.anova.signif, factor="extraction", pdf='AnovaSignifSpectralCounting.pdf')

# Créer un tableau contenant les résultats de l'anova du spectral counting et les résultats de l'ANOVA pour les protéines avec un effet traitement significatif
	dfspectral.count.anova.signif <- mcqGetDataframe(spectral.count.anova.signif)

# Exporter les résultats pour les protéines significatives au format csv
	mcqWriteCsv(spectral.count.anova.signif, 'spectral_count_anova_signif.csv')

