
mcqNewProteinValue = function (object) {
	if (class(object) == "mcqProtPep") {
		if("lognorm" %in% colnames(object@nona)) {

		}else {
			stop("no imputations in mcqProtPep object")
		}

		##### construction de la valeur de la protéine par somme des peptides.
# comme les données manquantes ont été remplacées, les sommes sont faites sur les mêmes peptides dans tous les échantillons.
# Ce sont les area et non des log qui doivent être sommés.
		tprot=aggregate(10^object@nona$lognorm,list(object@nona$protein,object@nona$msrun),FUN=sum)
		colnames(tprot)=c("protein","msrun","q")
		tprot$q=log10(tprot$q)
#réculération du descripteur
		prot.prot=unique(object@proteins[,c("protein","accession", "protein_description")])
		rownames(prot.prot) <- prot.prot$protein
		prot.prot$protein <- NULL

		tsamples = unique(object@peptides[,c("msrun","msrunfile")])
		rownames(tsamples) <- tsamples$msrun
		tsamples$msrun <- NULL


		#rename protein_description :
		colnames(prot.prot)[colnames(prot.prot) == "protein_description"] <- "descr"


		return (new ("mcqProtValue", metadata = object@metadata	, proteins = prot.prot, protval = tprot, samples = tsamples))

	}
	else {
		stop("input is not an mcqProtPep object")
	}
}


mcqReplaceNaProteinValueByMin = function (object) {
	if (class(object) == "mcqProtValue") {

		tacp= as.data.frame(tapply (object@protval$q, list(object@protval$protein,object@protval$msrun), FUN=sum))

# remplacement des données manquantes restantes (tous peptides manquant dans le msrun) par le minimum de la protéine dans l'expérience.
# Attention : part d'arbitraire ici. Mais ne concerne qu'un nbre minime de protéines normalement.
# On les compte:
		cat(paste("Number of protein quantities not available :",sum(is.na(tacp)),"\n"))

		min.prot=apply(tacp,1,min,na.rm=T)
		min.prot.mat=matrix(rep(min.prot,dim(tacp)[2]),nrow=dim(tacp[1]))
		min.prot.mat=as.data.frame(min.prot.mat)
		min.prot.mat[!is.na(tacp)]=0
		tacp[is.na(tacp)]=0
		tacp=tacp+min.prot.mat



# retour à format "1 colonne"
		tacp$protein=rownames(tacp)
		object@protval <- melt(tacp,na.rm=T) # na.rm=T: les données manquantes explicites dans le tacp  deviennent implicites (en principe on n'en a plus de toutes facons)
		colnames(object@protval)[colnames(object@protval)=="variable"]="msrun"
		colnames(object@protval)[colnames(object@protval)=="value"]="q"


		return (object)

	}
	else {
		stop("input is not an mcqProtValue object")
	}
}


mcqPlotProteinValueSd= function (object,pdf=NULL) {
	if (class(object) == "mcqProtValue") {

		#tacp= as.data.frame(tapply (object@protval$q, list(object@protval$protein,object@protval$msrun), FUN=sum))

		proteingroup=as.factor(object@protval$protein)
		## Suppression des peptiz dont l'écart-type du temps de rétention est trop élevé
		sdrt=aggregate(object@protval$q,list(proteingroup),FUN=sd)
		if (is.null(pdf)){
			par(ask=TRUE)
		}
		else{
			pdf(pdf)
		}
		hist(sdrt$x,nclass=100,main="Standard deviation of protein quantities",xlab="lognorm standard deviation")
		if (!is.null(pdf)){
			dev.off()
		}
	}
	else {
		stop("input is not an mcqProtValue object")
	}
}

mcqDropProteinValueSd= function (object, cutoff) {
	if (class(object) == "mcqProtValue") {

		#tacp= as.data.frame(tapply (object@protval$q, list(object@protval$protein,object@protval$msrun), FUN=sum))

		proteingroup=as.factor(object@protval$protein)
		## Suppression des peptiz dont l'écart-type du temps de rétention est trop élevé
		sdrt=aggregate(object@protval$q,list(proteingroup),FUN=sd)

		#On enlève les quelques cas particuliers où l'écart-type est supérieur à 15 (20 ?) car correspond certainement à un mismatch
		thr_sdrt=cutoff # paramètre à changer en fonction de l'histogramme
		badprot=sdrt[!is.na(sdrt$x) & sdrt$x<thr_sdrt,] # renvoie les lignes de rt pour lesquelles sdrt>thr_sdrt.
		badprot=drop.levels(badprot$Group.1)
		cat (paste(length(badprot), " proteins dropped\n"))

		object@protval <- subset(object@protval, !protein %in% badprot)
		object@protval <- drop.levels(object@protval)
		protok <- unique(object@protval$protein)
		object@proteins <- object@proteins[protok,]
		rownames(object@proteins) <- protok

		return (object)

	}
	else {
		stop("input is not an mcqProtValue object")
	}
}
#
#mcqGetProteinValueBySamples = function (object) {
#	if (class(object) == "mcqProtValue") {
#
#		pval <- merge(object@protval,object@proteins,all.y=F,by.x="protein",by.y="row.names")
#
#		tacp <- as.data.frame(tapply (pval$q, list(pval$accession,pval$msrun), FUN=sum))
#
#
#		return (tacp)
#
#	}
#	else {
#		stop("input is not an mcqProtValue object")
#	}
#}
