###################### correlation entre peptides de la même protéine
# principe: un ou des peptides d'une même protéine peuvent être mal corrélés aux autres pour différentes raisons, techniques ou biologiques (ex: MPT, variations alléliques, peptides éventuellement communs à protéines non identifiées).
# Queque soit la raison, ces peptides ne font qu'ajouter du bruit et on aura une mesure plus précise en les enlevant.
# Par la même occasion, on fait disparaître toutes les protéines qui ne sont représentées que par un seul peptiz. En toute rigueur, si on n'utilise pas ce module, on devrait au moins enlever les protéines représentées par un seul peptide.
# On enlève aussi non seulement toutes les protéines avec un seul peptide mais aussi toutes les protéines pour lesquelles aucun peptide n'est corrélé. Ca élimine tous les cas où un effet significatif important aurait pu être vu sur un seul peptide.

# On cherche le peptide le plus corrélé aux autres puis on ne retient que ceux qui lui sont bien corrélés
# # Attention: pour ne pas être soumis aux données aberrantes individuelles (ex: un accident dans un échantillon affecte beaucoup de peptides: cela crée une corrélation non intéressante entre epptides), je calcule la corrélation sur les traitements et non sur les données individuelles.
# Remarque: dans le cas de la manip sur les méthodes d'extraction ca ne fait qu'une corrélation à 4 points, ce qui est un peu limite.
# Dans le cas où on n'a que deux traitements, cette opération ne peut pas être faite (pas de corrélation calculable avec 2 points). Dans ce cas il vaut mieux quand même réduire à la liste des protéines représentées par au moins 2 peptides.
#remarque: dans les cas où 2 états de charges pour même peptide on ne devrait pas chercher de corrélation mais directememnt prendre leur somme car on n'a pas à faire un jugement de valeur sur la façon dont un peptide se retrouve tantôt 2 fois tantôt 3 fois chargé.

# attention: ici on utilise "extraction". Ca devrait être le niveau de regroupement minimal, par ex la combinaison genotype*traitement, ou le traitement s'il n'y a qu'un effet traitement.


# la fonction qui va retourner la liste de peptides bien corrélés entre eux
privcorrpept=function(object, factorName, myprot,seuil.corr) {
	if (class(object) == "mcqProtPep") {
		if("lognorm" %in% colnames(object@peptides)) {

		}else {
			stop("mcqProtPep object is not normalized")
		}
		subprot <- object@proteins[object@proteins$protein==myprot,]
		#print (subprot)

		sub <- object@peptides[object@peptides$peptide %in% subprot$peptide,c("msrun","lognorm","peptiz")]

		#print (sub[1:10,])
		#sub=tabok[tabok$protein==myprot,]
		#toto=tapply(sub$lognorm,list(sub$extraction,as.character(sub$peptiz)),FUN=mean,na.rm=T)
		sub <- merge(sub, object@metadata@metadata, by.x="msrun", by.y="row.names")
		toto=tapply(sub$lognorm,list(sub[,factorName],as.character(sub$peptiz)),FUN=mean,na.rm=T)

		ccc=cor(toto,use="pairwise.complete.obs")
		diag(ccc)=0
		ddd=ccc>seuil.corr
		ddd=apply(ddd,1,FUN=sum,na.rm=T)
		if (max(ddd)>0) {
			eee=ddd[ddd==max(ddd)]
			fff=names(eee[1])
			colok=ccc[which(colnames(ccc)==fff),]
			pepok=c(fff,names(colok[colok>seuil.corr]))
			# on ne veut pas plus de 30 peptiz par protéine. Sinon, risque de pb dans le modèle mixte (calcul du ddl).
			# donc si le nb de peptides corrélés est >30 on augmente le seuil jusqu'à ce qu'il passe en dessous.
			#de cette manière on réduit la liste en gardant les mieux corrélés entre eux.
			while(length(pepok)>30 & seuil.corr<1) {
				seuil.corr=seuil.corr+0.05
				cat(c("protein et seuil correlation",myprot,seuil.corr,"\n"))
				pepok=c(fff,names(colok[colok>seuil.corr]))
			}
		}
		else {
			pepok=NULL
		}
		return(pepok)
	}
	else {
		stop("input is not an mcqProtPep object")
	}
}


mcqDropUncorrelatedPeptides<- function (object, factorName, min.corr = 0.75) {
	if (class(object) == "mcqProtPep") {
		if (factorName %in% colnames(object@metadata@metadata)) {

		}
		else {
			stop(paste("the factor ",factorName," is not described in your metadata"))
		}
		if("lognorm" %in% colnames(object@peptides)) {

		}else {
			stop("mcqProtPep object is not normalized")
		}
		if (length(levels(object@metadata@metadata[,factorName])) < 3) {
			stop(paste("the factor ",factorName," should at least have 3 or more states to process correlations"))
		}

		# on a maintenant besoin que tabok contienne les données de traitement
		# juste bidouille parce qu'on traine toujours à la fois msrun et msrunfile, il faudra s'en débarasser.
		#tabok=tabok[,-which(colnames(tabok)=="msrunfile"]
		#tabok=merge(tabok, traitement,by="msrun")
		#tabok=drop.levels(tabok) # par sécurité. eEn principe non nécessaire.

		proteins <- levels(object@proteins$protein)
		nbprot <- length(proteins)

		cat(paste("Nb de protéines avant sélection par les corrélations:",length(proteins),"\n"))
		pepoktot=NULL
		for (i in 1:nbprot){
			bestPepCorr <- privcorrpept(object, factorName, proteins[i],min.corr)
			#print (bestPepCorr)
			if (!is.null(bestPepCorr)) {
				pepoktot=c(pepoktot,bestPepCorr)
			}
			if (i%%100==0) cat(paste("looking for best corr peptides for protein ",i," out of ",nbprot,"\n"))
		}

		object@peptides <- object@peptides[object@peptides$peptiz %in% pepoktot,]
		object@peptides <- drop.levels(object@peptides)

		pepok <- levels(object@peptides$peptide)
		object@proteins <- object@proteins[object@proteins$peptide %in% pepok,]
		object@proteins <- drop.levels(object@proteins)

		cat(paste("Nb de peptiz après sélection par les corrélations:",length(pepoktot),"\n"))
		cat(paste("Nb de protéines après sélection par les corrélations:",length(levels(object@proteins$protein)),"\n"))

		#save(tabok,file="tabokpep.RData")

		return (object)

	}
	else {
		stop("input is not an mcqProtPep object")
	}
}

