library(gplots)

mcqPlotHeatmap= function (qprot,factor=NULL, pdf=NULL) {
	if (class(qprot) != "mcqProtValue") {
		stop("your object is not an mcqProtValue object")
	}

	if (is.null(factor)) {
		stop("You must choose a factor")
		#factorname <- colnames(qprot@metadata@metadata)[1]
	}
	else {
  		factorname <- factor
	}
	if(factorname %in% names(qprot@metadata@metadata)) {
	}else {
		stop(paste("factor ", factorname, " is not described in your mcqProtValue metadata"))
	}


	tprot.signif <- merge(qprot@protval, qprot@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@samples, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@proteins, by.x="protein", by.y="row.names")

	if (is.null(pdf)){
		par(ask=TRUE)
	}
	else{
		pdf(pdf,title="Classification")
	}

	tprot.signif$echantillon=paste(tprot.signif[,factorname],tprot.signif$msrun,sep="-")

	tacp= tapply (tprot.signif$q, list(tprot.signif$accession,tprot.signif$echantillon), FUN=sum)

	### heatmap + dendro
	dendro=heatmap.2(tacp,scale="row",Rowv=T,trace="none")

	if (!is.null(pdf)){
		dev.off()
	}

}

mcqPlotHeatmapMeanRep= function (qprot,factor=NULL,pdf=NULL) {
	if (class(qprot) != "mcqProtValue") {
		stop("your object is not an mcqProtValue object")
	}
	if (is.null(factor)) {
		stop("You must choose a factor")
		#factorname <- colnames(qprot@metadata@metadata)[1]
	}
	else {
		factorname <- factor
	}
	
	if(factorname %in% names(qprot@metadata@metadata)) {
	}
	else {
		stop(paste("factor ", factorname, " is not described in your mcqProtValue metadata"))
	}


	tprot.signif <- merge(qprot@protval, qprot@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@samples, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@proteins, by.x="protein", by.y="row.names")


	if (is.null(pdf)){
		par(ask=TRUE)
	}
	else{
		pdf(pdf,title="Classification by conditions")
	}

	# On calcule la moyenne des replicats par conditions
	tacp= tapply(tprot.signif$q,list(tprot.signif$descr,tprot.signif[,factorname]),FUN=mean)

	### heatmap + dendro
	dendro=heatmap.2(tacp,scale="row",Rowv=T,trace="none")

	if (!is.null(pdf)){
		dev.off()
	}

}

mcqPlotCluster= function (qprot,factor=NULL, nbclust=8, pdf=NULL) {
	if (class(qprot) != "mcqProtValue") {
		stop("your object is not an mcqProtValue object")
	}
	if (is.null(factor)) {
		stop("You must choose a factor")
		#factorname <- colnames(qprot@metadata@metadata)[1]
	}
	else {
		factorname <- factor
	}
	
	if(factorname %in% names(qprot@metadata@metadata)) {
	}else {
		stop(paste("factor ", factorname, " is not described in your mcqProtValue metadata"))
	}

	tprot.signif <- merge(qprot@protval, qprot@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@samples, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@proteins, by.x="protein", by.y="row.names")

	if (is.null(pdf)){
		par(ask=TRUE)
	}
	else{
		pdf(pdf,title="Classification")
	}

	tprot.signif$echantillon=paste(tprot.signif[,factorname],tprot.signif$msrun,sep="-")

	tacp= tapply (tprot.signif$q, list(tprot.signif$accession,tprot.signif$echantillon), FUN=sum)


	### clustering methode SOTA (Self-Organizing Tree Algorithm)
	#library("clValid")

	tacp.scale=t(scale(t(tacp))) # centrage-reduction sur les lignes (les protéines)
	#nbclust=8 # à parametrer: nb de clusters voulu
	cl.sota <- sota(tacp.scale, nbclust-1)
	plot(cl.sota)

	tacp.clust=data.frame(tacp.scale,cl.sota=cl.sota$clust)


	for (i in 1:nbclust) {
		cl=tacp.clust[tacp.clust$cl.sota==i,]
		cl$cl.sota=NULL
		matplot(t(cl),type="l",col="gray",lty=1,xaxt="none",ylab="scaled values",main=paste("Cluster",i))
		axis(1,outer=FALSE,labels=colnames(tacp),cex.axis=0.7,hadj=1,padj=0,las=2,at=1:length(colnames(tacp)))
		mtext(paste("Nb proteines:",cl.sota$totals[i]),side=3,line=1,adj=0)

		mmm=apply(cl,2,FUN=mean)
		matlines(mmm,col="red")
	}

	if (!is.null(pdf)){
		dev.off()
	}

}

mcqPlotClusterMeanRep= function (qprot,factor=NULL, nbclust=8, pdf=NULL) {
	if (class(qprot) != "mcqProtValue") {
		stop("your object is not an mcqProtValue object")
	}

	if (is.null(factor)) {
		stop("You must choose a factor")
		#factorname <- colnames(qprot@metadata@metadata)[1]
	}
	else {
		factorname <- factor
	}
	
	if(factorname %in% names(qprot@metadata@metadata)) {
	}else {
		stop(paste("factor ", factorname, " is not described in your mcqProtValue metadata"))
	}

	tprot.signif <- merge(qprot@protval, qprot@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@samples, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@proteins, by.x="protein", by.y="row.names")


	if (is.null(pdf)){
		par(ask=TRUE)
	}
	else{
		pdf(pdf,title="Classification")
	}

	# On calcule la moyenne des replicats par conditions
	tacp= tapply(tprot.signif$q,list(tprot.signif$accession,tprot.signif[,factorname]),FUN=mean)


	### clustering methode SOTA (Self-Organizing Tree Algorithm)
	#library("clValid")

	tacp.scale=t(scale(t(tacp))) # centrage-reduction sur les lignes (les protéines)
	#nbclust=8 # à parametrer: nb de clusters voulu
	cl.sota <- sota(tacp.scale, nbclust-1)
	#plot(cl.sota)

	tacp.clust=data.frame(tacp.scale,cl.sota=cl.sota$clust)


	for (i in 1:nbclust) {
		cl=tacp.clust[tacp.clust$cl.sota==i,]
		cl$cl.sota=NULL
		matplot(t(cl),type="l",col="gray",lty=1,xaxt="none",ylab="scaled values",main=paste("Cluster",i))
		axis(1,outer=FALSE,labels=colnames(tacp),cex.axis=0.7,hadj=1,padj=0,las=2,at=1:length(colnames(tacp)))
		mtext(paste("Nb proteines:",cl.sota$totals[i]),side=3,line=1,adj=0)

		mmm=apply(cl,2,FUN=mean)
		matlines(mmm,col="red")
	}

	if (!is.null(pdf)){
		dev.off()
	}

}

mcqClusterMeanRepInfoWriteCsv= function (qprot,factor=NULL, nbclust=8, file="cluster.csv") {
	if (class(qprot) != "mcqProtValue") {
		stop("your object is not an mcqProtValue object")
	}

	if (is.null(factor)) {
		stop("You must choose a factor")
		#factorname <- colnames(qprot@metadata@metadata)[1]
	}
	else {
		factorname <- factor
	}
	
	if(factorname %in% names(qprot@metadata@metadata)) {
	}else {
		stop(paste("factor ", factorname, " is not described in your mcqProtValue metadata"))
	}

	tprot.signif <- merge(qprot@protval, qprot@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@samples, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, qprot@proteins, by.x="protein", by.y="row.names")

	# On calcule la moyenne des replicats par conditions
	tacp= tapply(tprot.signif$q,list(tprot.signif$accession,tprot.signif[,factorname]),FUN=mean)
	### clustering methode SOTA (Self-Organizing Tree Algorithm)
	#library("clValid")

	tacp.scale=t(scale(t(tacp))) # centrage-reduction sur les lignes (les protéines)

	cl.sota <- sota(tacp.scale, nbclust-1)

	tacp.clust=data.frame(tacp.scale,cl.sota=cl.sota$clust)
	tacp.clust=merge(tacp.clust,qprot@proteins,by.x="row.names",by.y="accession")
	colnames(tacp.clust)[1]=""
	#accession=rownames(tacp.clust)
	#tacp.clust=cbind(protein,tacp.clust)
	write.table(tacp.clust,file, quote= FALSE,  sep="\t", dec=".",row.names=F)
}

# ATTENTION a corriger :
mcqPlotCineticMeanRep= function (protval, protanova, nbclust=8, pdf=NULL) {
	if (class(protval) != "mcqProtValue") {
		stop("first argument is not an mcqProtValue object")
	}
	if (class(protanova) != "mcqProtAnova") {
		stop("second argument is not an mcqProtAnova object")
	}

	### on travaille sur les signif:
	tprot.signif.list <- mcqProteinAnovaGetSignif(protanova)

	tprot.signif <- protval@protval[protval@protval$protein %in% tprot.signif.list,]

	factorname <- colnames(protanova@metadata@metadata)[1]
	if(factorname %in% names(protval@metadata@metadata)) {
	}else {
		stop(paste("factor ", factorname, " is not described in your mcqProtValue metadata"))
	}

	tprot.signif <- merge(tprot.signif, protval@metadata@metadata, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, protval@samples, by.x="msrun", by.y="row.names")
	tprot.signif <- merge(tprot.signif, protval@proteins, by.x="protein", by.y="row.names")


	tprot.signif=drop.levels(tprot.signif)
	### remarque: on n'a pas enlevé les signif dont la variation est faible
	# On calcule la moyenne des replicats par conditions
	tacp= tapply(tprot.signif$q,list(tprot.signif$accession,tprot.signif[,factorname]),FUN=mean)
	### clustering methode SOTA (Self-Organizing Tree Algorithm)
	#library("clValid")

	tacp.scale=t(scale(t(tacp))) # centrage-reduction sur les lignes (les protéines)

	cl.sota <- sota(tacp.scale, nbclust-1)

	tacp.clust=data.frame(tacp.scale,cl.sota=cl.sota$clust)

	if (is.null(pdf)){
		par(ask=TRUE)
	}
	else{
		pdf(pdf,title="Cinetique")
	}

	for (i in 1:nbclust) {
		cl=tacp.clust[tacp.clust$cl.sota==i,]
		cl$cl.sota=NULL
		# sera a parametrer
		matplot(t(cl[1:3]),ylim=c(min(t(cl)),max(t(cl))),type="l",col="gray",lty=1,xaxt="none",ylab="scaled values",main=paste("Cinetic : Cluster",i))
		mmm=apply(cl[1:3],2,FUN=mean)
		matlines(mmm,col="red",lty=1)
		matlines(t(cl[4:6]),col="gray",lty=2)
		mmm=apply(cl[4:6],2,FUN=mean)
		matlines(mmm,col="blue",lty=2)
		# a tester : pour la legende prendre les levels du factorname
		legend("topright", legend = c("Glu", "Gly"), col = c("red", "blue"), pch = 15, bty = "n")
	}
	if (!is.null(pdf)){
		dev.off()
	}

}